"use strict";
/*
 * Copyright 2015 Palantir Technologies, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DialogFooter = void 0;
var tslib_1 = require("tslib");
var classnames_1 = tslib_1.__importDefault(require("classnames"));
var React = tslib_1.__importStar(require("react"));
var common_1 = require("../../common");
/**
 * Dialog footer component.
 *
 * @see https://blueprintjs.com/docs/#core/components/dialog.dialog-footer-props
 */
var DialogFooter = /** @class */ (function (_super) {
    tslib_1.__extends(DialogFooter, _super);
    function DialogFooter() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DialogFooter.prototype.render = function () {
        var _a;
        return (React.createElement("div", { className: (0, classnames_1.default)(common_1.Classes.DIALOG_FOOTER, this.props.className, (_a = {},
                _a[common_1.Classes.DIALOG_FOOTER_FIXED] = !this.props.minimal,
                _a)) },
            this.renderMainSection(),
            this.maybeRenderActionsSection()));
    };
    /** Render the main footer section (left aligned). */
    DialogFooter.prototype.renderMainSection = function () {
        return React.createElement("div", { className: common_1.Classes.DIALOG_FOOTER_MAIN_SECTION }, this.props.children);
    };
    /** Optionally render the footer actions (right aligned). */
    DialogFooter.prototype.maybeRenderActionsSection = function () {
        var actions = this.props.actions;
        if (actions == null) {
            return undefined;
        }
        return React.createElement("div", { className: common_1.Classes.DIALOG_FOOTER_ACTIONS }, actions);
    };
    DialogFooter.defaultProps = {
        minimal: false,
    };
    return DialogFooter;
}(common_1.AbstractPureComponent2));
exports.DialogFooter = DialogFooter;
//# sourceMappingURL=dialogFooter.js.map